import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;

public class MovieCharacter implements ActiveRecord {
	private long movCharId;
	private String character;
	private String alias;
	private int position;
	private long playedBy;
	
	public MovieCharacter(long movCharId, String character, String alias, int position, long playedBy) {
		this.movCharId = movCharId;
		this.character = character;
		this.alias = alias;
		this.position = position;
		this.playedBy = playedBy;
	}
	
	public String getCharacter() {
		return character;
	}

	public void setCharacter(String character) {
		this.character = character;
	}

	public String getAlias() {
		return alias;
	}

	public void setAlias(String alias) {
		this.alias = alias;
	}

	public int getPosition() {
		return position;
	}

	public void setPosition(int position) {
		this.position = position;
	}

	public long getPlayedBy() {
		return playedBy;
	}

	public void setPlayedBy(long playedBy) {
		this.playedBy = playedBy;
	}

	public long getMovCharId() {
		return movCharId;
	}

	@Override
	public void insert() throws SQLException {
		String sql = "INSERT INTO `MovieCharacter` VALUES (?, ?, ?, ?, ?);";
		try (PreparedStatement ps = ConnectionManager.getConnection().prepareStatement(sql)) {
			ps.setLong(1,  this.movCharId);
			ps.setString(2,  this.character);
			ps.setString(3,  this.alias);
			ps.setInt(4, this.position);
			ps.setLong(5, this.playedBy);
			ps.executeUpdate();
		}		
	}

	@Override
	public void update() throws SQLException {
		String sql = "UPDATE `MovieCharacter` SET `Character`=?, `Alias`=?, `Position`=?, `PlayedBy`=? WHERE `MovCharID`=?";
		try (PreparedStatement ps = ConnectionManager.getConnection().prepareStatement(sql)) {
			ps.setString(1,  this.character);
			ps.setString(2,  this.alias);
			ps.setInt(3, this.position);
			ps.setLong(4, this.playedBy);
			ps.setLong(5,  this.movCharId);
			ps.executeUpdate();
		}
	}

	@Override
	public void delete() throws SQLException {
		String sql = "DELETE FROM `MovieCharacter` WHERE `MovCharID`=?";
		try (PreparedStatement ps = ConnectionManager.getConnection().prepareStatement(sql)) {
			ps.setLong(1,  this.movCharId);
			ps.executeUpdate();
		}
	}
	
	@Override
	public String toString() {
		return "Character: " + this.movCharId + " : " + this.character + " aka. " + this.alias + " - " + this.position + " : " + this.playedBy;
	}
	
	public static ArrayList<MovieCharacter> findAll() throws SQLException {
		String sql = "SELECT * FROM MovieCharacter";
		ArrayList<MovieCharacter> movieCharacters = new ArrayList<MovieCharacter>();
		try (PreparedStatement ps = ConnectionManager.getConnection().prepareStatement(sql)) {
			try (ResultSet rs = ps.executeQuery()) {
				int i = 0;
				while (rs.next()) {
					movieCharacters.add(new MovieCharacter(rs.getLong("MovCharID"), rs.getString("Character"), rs.getString("Alias"), rs.getInt("Position"), rs.getLong("PlayedBy")));
				}
			}
		}
		return movieCharacters;
	}
	
}
